set_isr_service_flag_unchecked

Function set_isr_service_flag_unchecked 

pub unsafe fn set_isr_service_flag_unchecked()
Notifies this GPIO driver that the GPIO ISR service has already been initialized. This prevents an error as this driver would otherwise attempt to initialize it again.

Safety

The caller must ensure that gpio_install_isr_service has already been invoked elsewhere. This should only be ever needed when interfacing external code that touches the GPIO ISR service.