pub struct Gpio3<'a>(/* private fields */);Implementations
Sourceimpl Gpio3<'_>
impl Gpio3<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub unsafe fn reborrow(&mut self) -> Gpio3<'_>
pub unsafe fn reborrow(&mut self) -> Gpio3<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
Safety
You must ensure that you are not using reborrowed peripherals in drivers which are
forgotten via core::mem::forget.
Sourceimpl<'a> Gpio3<'a>
impl<'a> Gpio3<'a>
pub fn degrade_input(self) -> AnyInputPin<'a>
Sourceimpl<'a> Gpio3<'a>
impl<'a> Gpio3<'a>
pub fn degrade_output(self) -> AnyOutputPin<'a>
pub fn degrade_input_output(self) -> AnyIOPin<'a>