Struct Pins
Source pub struct Pins {Show 22 fields
pub gpio0: Gpio0<'static>,
pub gpio1: Gpio1<'static>,
pub gpio2: Gpio2<'static>,
pub gpio3: Gpio3<'static>,
pub gpio4: Gpio4<'static>,
pub gpio5: Gpio5<'static>,
pub gpio6: Gpio6<'static>,
pub gpio7: Gpio7<'static>,
pub gpio8: Gpio8<'static>,
pub gpio9: Gpio9<'static>,
pub gpio10: Gpio10<'static>,
pub gpio11: Gpio11<'static>,
pub gpio12: Gpio12<'static>,
pub gpio13: Gpio13<'static>,
pub gpio14: Gpio14<'static>,
pub gpio15: Gpio15<'static>,
pub gpio16: Gpio16<'static>,
pub gpio17: Gpio17<'static>,
pub gpio18: Gpio18<'static>,
pub gpio19: Gpio19<'static>,
pub gpio20: Gpio20<'static>,
pub gpio21: Gpio21<'static>,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.